getWidget property
The function to use to get a title for the resulting ListTiles.
If this value is null, then toString will be used.
Implementation
final Widget Function(T value)? getWidget;
The function to use to get a title for the resulting ListTiles.
If this value is null, then toString will be used.
final Widget Function(T value)? getWidget;