SimpleScaffold class

A quicker way to create scaffolds.

Inheritance

Constructors

SimpleScaffold({required String title, required Widget body, Widget? leading, List<Widget> actions = const [], PreferredSizeWidget? bottom, Widget? bottomNavigationBar, Widget? floatingActionButton, Key? key})
Create an instance.
const

Properties

actions → List<Widget>
App bar actions.
final
body → Widget
The body of the scaffold.
final
bottom → PreferredSizeWidget?
The AppBar.bottom widget.
final
bottomNavigationBar → Widget?
The Scaffold.bottomNavigationBar widget.
final
floatingActionButton → Widget?
The floating action button to use.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
The value of AppBar.leading.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The title of the scaffold.
final

Methods

build(BuildContext context) → Widget
Build the widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited