TabbedScaffoldTab class

A tab for a TabbedScaffold.

Constructors

TabbedScaffoldTab({required String title, required Widget icon, required Widget child, Widget? leading, List<Widget>? actions, Widget? floatingActionButton, String? tooltip, bool enabled = true, bool autofocus = false})
Create an instance.
const

Properties

actions → List<Widget>?
The actions to use for the app bar.
final
autofocus → bool
Whether this tab should be autofocused.
final
child → Widget
The widget below this widget in the tree.
final
enabled → bool
Whether this page is enabled.
final
floatingActionButton → Widget?
The floating action button to use.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget
The icon to use for the BottomNavigationBarItem that shows this tab.
final
leading → Widget?
The value for AppBar.leading.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
The title of the scaffold.
final
tooltip → String?
The tooltip to use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited