commandIsRegistered method
Returns a boolean indicating whether command is registered with this
widget.
Implementation
bool commandIsRegistered(VoidCallback command) => _commands.contains(command);
Returns a boolean indicating whether command is registered with this
widget.
bool commandIsRegistered(VoidCallback command) => _commands.contains(command);